@@ -249,6 +249,29 @@ class DataFramePlot:
         )
         fig.show()
 
+    def plot_global_fit(self, args_plot: PlotAPI, df: pd.DataFrame) -> None:
+        """Plot the global dataframe according to the PlotAPI arguments.
+
+        Args:
+            args_plot (PlotAPI): PlotAPI object for the settings of the plot.
+            df (pd.DataFrame): Dataframe to plot.
+        """
+        for i in range(
+            1,
+            sum(1 for _col in df.columns if _col.startswith(ColumnNamesAPI().fit)) + 1,
+        ):
+            _col = [col for col in df.columns if col.endswith(str(i))]
+            _col.append(ColumnNamesAPI().energy)
+            _df = df[_col]
+            _df = _df.rename(
+                columns={
+                    f"{ColumnNamesAPI().intensity}_{i}": ColumnNamesAPI().intensity,
+                    f"{ColumnNamesAPI().fit}_{i}": ColumnNamesAPI().fit,
+                    f"{ColumnNamesAPI().residual}_{i}": ColumnNamesAPI().residual,
+                }
+            )
+            self.plot_2dataframes(args_plot, _df)
+
     def plot_metric(
         self,
         args_plot: PlotAPI,
@@ -343,7 +366,8 @@ class DataFramePlot:
         )
         return fig
 
-    def title_text(self, name: str, unit: Optional[str] = None) -> str:
+    @staticmethod
+    def title_text(name: str, unit: Optional[str] = None) -> str:
         """Return the title text.
 
         Args:
@@ -384,7 +408,7 @@ class ExportResults:
                  and suffix.
         """
         df.to_csv(
-            self.fname2Path(
+            self.fname2path(
                 fname=args.fname,
                 prefix=args.prefix,
                 suffix=args.suffix,
@@ -402,7 +426,7 @@ class ExportResults:
                  and suffix.
         """
         with open(
-            self.fname2Path(
+            self.fname2path(
                 fname=args.fname,
                 prefix=args.prefix,
                 suffix=args.suffix,
@@ -413,7 +437,7 @@ class ExportResults:
             tomli_w.dump(report, f)
 
     @staticmethod
-    def fname2Path(
+    def fname2path(
         fname: str,
         suffix: str,
         prefix: Optional[str] = None,
@@ -463,7 +487,7 @@ class SolverResults:
 
     @property
     def settings_configurations(self) -> Dict[str, Any]:
-        """Configuration settings.
+        """Configure settings.
 
         Returns:
             Dict[str, Any]: Configuration settings.
@@ -474,10 +498,6 @@ class SolverResults:
     def get_gof(self) -> Dict[str, float]:
         """Get the goodness of fit values.
 
-        Args:
-            export_df (bool, optional): Export the dictionary as dataframe, if True.
-                 Defaults to False.
-
         Returns:
             Dict[str, float]: Goodness of fit values as dictionary.
         """
@@ -664,7 +684,7 @@ class ExportReport(SolverResults):
             linear_correlation=self.get_linear_correlation,
             component_correlation=self.get_component_correlation,
             confidence_interval=self.get_confidence_interval,
-            covariance_matrix=self.get_component_correlation,
+            covariance_matrix=self.get_covariance_matrix,
             variables=self.get_variables,
             errorbars=self.get_errorbars,
         )
@@ -692,9 +712,7 @@ class ExportReport(SolverResults):
         ).dict(exclude_none=True)
 
 
-class SpectraFitNotebook(
-    DataFramePlot, DataFrameDisplay, ExportResults, ExportReport, SolverResults
-):
+class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
     """Jupyter Notebook plugin for SpectraFit."""
 
     args: Dict[str, Any]
@@ -703,6 +721,7 @@ class SpectraFitNotebook(
     df_fit: pd.DataFrame
     df_pre: pd.DataFrame = pd.DataFrame()
     df_metric: pd.DataFrame = pd.DataFrame()
+    df_peaks: pd.DataFrame = pd.DataFrame()
     initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]]
 
     def __init__(
@@ -934,10 +953,12 @@ class SpectraFitNotebook(
             args_plot=self.args_plot, df_1=self.df_pre, df_2=self.df_org
         )
 
-    @property
     def plot_fit_df(self) -> None:
         """Plot the fit."""
-        self.plot_2dataframes(args_plot=self.args_plot, df_1=self.df_fit)
+        if self.global_ == 1:
+            self.plot_global_fit(args_plot=self.args_plot, df=self.df_fit)
+        else:
+            self.plot_2dataframes(args_plot=self.args_plot, df_1=self.df_fit)
 
     def plot_current_metric(
         self,
@@ -993,6 +1014,7 @@ class SpectraFitNotebook(
         show_plot: bool = True,
         show_metric: bool = True,
         show_df: bool = False,
+        show_peaks: bool = False,
         conf_interval: Union[bool, Dict[str, Any]] = False,
         bar_criteria: Optional[Union[str, List[str]]] = None,
         line_criteria: Optional[Union[str, List[str]]] = None,
@@ -1008,6 +1030,7 @@ class SpectraFitNotebook(
             show_metric (bool, optional): Show the metric of the fit. Defaults to True.
             show_df (bool, optional): Show current fit results as dataframe. Defaults
                  to False.
+            show_peaks (bool, optional): Show the peaks of fit. Defaults to False.
             conf_interval (Union[bool,Dict[str, Any]], optional): Bool or dictionary for
                  the parameter with the parameter for calculating the confidence
                  interval. Using `conf_interval=False` turns of the calculation of
@@ -1051,9 +1074,10 @@ class SpectraFitNotebook(
                 },
             )(),
         )()
-        self.update_metric
+        self.update_metric()
+        self.update_peaks()
         if show_plot:
-            self.plot_fit_df
+            self.plot_fit_df()
 
         if show_metric:
             self.plot_current_metric(
@@ -1063,7 +1087,36 @@ class SpectraFitNotebook(
         if show_df:
             self.interactive_display(df=self.df_fit)
 
-    @property
+        if show_peaks:
+            self.interactive_display(df=self.df_peaks)
+
+    def update_peaks(self) -> None:
+        """Update the peaks dataframe as multi-column dataframe.
+
+        The multi-column dataframe is used for the interactive display of the
+        peaks with initial, current (model), and best fit values.
+        """
+        tuples = []
+        _list = []
+        for key_1, _dict in self.args["fit_insights"]["variables"].items():
+            tuples.extend([(key_1, key_2) for key_2, val in _dict.items()])
+            _list.extend([val for _, val in _dict.items()])
+
+        self.df_peaks = pd.concat(
+            [
+                self.df_peaks,
+                pd.DataFrame(
+                    pd.Series(
+                        _list,
+                        index=pd.MultiIndex.from_tuples(
+                            tuples, names=["component", "parameter"]
+                        ),
+                    )
+                ).T,
+            ],
+            ignore_index=True,
+        )
+
     def update_metric(self) -> None:
         """Update the metric dataframe."""
         self.df_metric = pd.concat(
